jammy.cli package
=================

Submodules
----------

jammy.cli.argument module
-------------------------

.. automodule:: jammy.cli.argument
   :members:
   :undoc-members:
   :show-inheritance:

jammy.cli.cmdline\_viz module
-----------------------------

.. automodule:: jammy.cli.cmdline_viz
   :members:
   :undoc-members:
   :show-inheritance:

jammy.cli.colors module
-----------------------

.. automodule:: jammy.cli.colors
   :members:
   :undoc-members:
   :show-inheritance:

jammy.cli.device module
-----------------------

.. automodule:: jammy.cli.device
   :members:
   :undoc-members:
   :show-inheritance:

jammy.cli.keyboard module
-------------------------

.. automodule:: jammy.cli.keyboard
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: jammy.cli
   :members:
   :undoc-members:
   :show-inheritance:
